@@ -6,8 +6,7 @@ import logging
 from typing import Optional
 from urllib.request import urlopen
 
-from .utils import confirm
-from .common import Fx, Emotion
+from .common import Fx, Emotion, confirm
 
 Log = logging.getLogger(__name__)
 
@@ -150,6 +149,4 @@ class GitignoreGenetor(object):
                 print("#" * 60)
                 print(ignore_content)
             else:
-                print(
-                    "Write gitignore file successful. {0}".format(Emotion.Icon_Smiler)
-                )
+                print("Write gitignore file successful. {0}".format(Emotion.smiler))
